@@ -14,8 +14,6 @@ To execute all Jupyter notebooks in a folder recursively:
 
 """
 
-# Authors: Dr. Qiusheng Wu (https://wetlands.io)
-# License: MIT
 
 import os
 import pkg_resources
@@ -95,7 +93,7 @@ def format_params(line, sep=":"):
     # print(line)
     new_line = line
     prefix = ""
-    suffix = ""
+    # suffix = ""
 
     if line.strip().startswith("for"):  # skip for loop
         return line
@@ -286,7 +284,7 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
         github_repo (str, optional): GitHub repo url. Defaults to None.
 
     Returns:
-        list : Python script
+        list: Python script
     """
     in_file = os.path.abspath(in_file)
     if out_file is None:
@@ -299,7 +297,7 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
         out_file = os.path.join(root_dir, out_file)
 
     is_python = False
-    add_github_url = False
+    # add_github_url = False
     qgis_import_str = ""
     if use_qgis:
         qgis_import_str = "from ee_plugin import Map \n"
@@ -312,7 +310,7 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
     math_import_str = ""
 
     lines = []
-    with open(in_file) as f:
+    with open(in_file, encoding="utf-8") as f:
         lines = f.readlines()
 
         math_import = use_math(lines)
@@ -332,10 +330,10 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
     else:  # deal with JavaScript
 
         header = github_url + "import ee \n" + qgis_import_str + math_import_str
-        function_defs = []
+        # function_defs = []
         output = header + "\n"
 
-        with open(in_file) as f:
+        with open(in_file, encoding="utf-8") as f:
             lines = f.readlines()
 
             # print('Processing {}'.format(in_file))
@@ -355,9 +353,10 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
                     or line.strip().startswith("function")
                 ):
                     bracket_index = line.index("{")
-                    matching_line_index, matching_char_index = find_matching_bracket(
-                        lines, index, bracket_index
-                    )
+                    (
+                        matching_line_index,
+                        matching_char_index,
+                    ) = find_matching_bracket(lines, index, bracket_index)
 
                     line = line[:bracket_index] + line[bracket_index + 1 :]
                     if matching_line_index == index:
@@ -393,9 +392,10 @@ def js_to_python(in_file, out_file=None, use_qgis=True, github_repo=None):
                         )
                 elif "{" in line:
                     bracket_index = line.index("{")
-                    matching_line_index, matching_char_index = find_matching_bracket(
-                        lines, index, bracket_index
-                    )
+                    (
+                        matching_line_index,
+                        matching_char_index,
+                    ) = find_matching_bracket(lines, index, bracket_index)
                     if (matching_line_index == index) and (":" in line):
                         pass
                     elif ("for (" in line) or ("for(" in line):
@@ -484,7 +484,11 @@ def create_new_cell(contents, replace=False):
 
 
 def js_snippet_to_py(
-    in_js_snippet, add_new_cell=True, import_ee=True, import_geemap=True, show_map=True
+    in_js_snippet,
+    add_new_cell=True,
+    import_ee=True,
+    import_geemap=True,
+    show_map=True,
 ):
     """Converts an Earth Engine JavaScript snippet wrapped in triple quotes to Python directly on a Jupyter notebook.
 
@@ -513,9 +517,9 @@ def js_snippet_to_py(
         if import_geemap:
             out_lines.append("import geemap\n\n")
             out_lines.append("Map = geemap.Map()\n")
-        if import_ee:
-            out_lines.append("ee.Initialize()\n")
-        with open(out_py) as f:
+        # if import_ee:
+        #     out_lines.append("ee.Initialize()\n")
+        with open(out_py, encoding="utf-8") as f:
             lines = f.readlines()
             for index, line in enumerate(lines):
                 if index < (len(lines) - 1):
@@ -602,7 +606,7 @@ def remove_qgis_import(in_file):
     """
     in_file = os.path.abspath(in_file)
     start_index = 0
-    with open(in_file) as f:
+    with open(in_file, encoding="utf-8") as f:
         lines = f.readlines()
         for index, line in enumerate(lines):
             if "from ee_plugin import Map" in line:
@@ -693,7 +697,7 @@ def template_header(in_template):
     template_lines = []
     header_end_index = 0
 
-    with open(in_template) as f:
+    with open(in_template, encoding="utf-8") as f:
         template_lines = f.readlines()
         for index, line in enumerate(template_lines):
             if "## Add Earth Engine Python script" in line:
@@ -717,7 +721,7 @@ def template_footer(in_template):
     template_lines = []
     footer_start_index = 0
 
-    with open(in_template) as f:
+    with open(in_template, encoding="utf-8") as f:
         template_lines = f.readlines()
         for index, line in enumerate(template_lines):
             if "## Display Earth Engine data layers" in line:
@@ -729,7 +733,11 @@ def template_footer(in_template):
 
 
 def py_to_ipynb(
-    in_file, template_file, out_file=None, github_username=None, github_repo=None
+    in_file,
+    template_file,
+    out_file=None,
+    github_username=None,
+    github_repo=None,
 ):
     """Converts Earth Engine Python script to Jupyter notebook.
 
@@ -774,7 +782,7 @@ def py_to_ipynb(
             new_header.append(line)
         header = new_header
 
-    if content != None:
+    if content is not None:
         out_text = header + content + footer
     else:
         out_text = header + footer
@@ -790,9 +798,10 @@ def py_to_ipynb(
         command = 'ipynb-py-convert "{}" "{}"'.format(out_py_file, out_file)
         print(os.popen(command).read().rstrip())
         # os.popen(command)
-    except:
+    except Exception as e:
         print("Please install ipynb-py-convert using the following command:\n")
         print("pip install ipynb-py-convert")
+        raise Exception(e)
 
     # os.remove(out_py_file)
 
@@ -888,11 +897,11 @@ def update_nb_header(in_file, github_username=None, github_repo=None):
 
     output_lines = []
 
-    with open(in_file) as f:
+    with open(in_file, encoding="utf-8") as f:
         lines = f.readlines()
         start_line_index = 2
         start_char_index = lines[start_line_index].index("{")
-        matching_line_index, matching_char_index = find_matching_bracket(
+        matching_line_index, _ = find_matching_bracket(
             lines, start_line_index, start_char_index
         )
 
@@ -1019,13 +1028,12 @@ def download_gee_app(url, out_file=None):
 
     try:
         urllib.request.urlretrieve(json_url, json_path)
-    except:
-        print("The URL is invalid. Please double check the URL.")
-        return
+    except Exception:
+        raise Exception("The URL is invalid. Please double check the URL.")
 
     with open(out_file_path, "w") as f1:
 
-        with open(json_path) as f2:
+        with open(json_path, encoding="utf-8") as f2:
             lines = f2.readlines()
             for line in lines:
                 # print(line)
